==> ejc-procurement-impl-3.0.0-20251203.120921-26-sources.jar: com/ejianc/business/procurement/plan/bean/PurchasePlanDetailEntity.java <==
package com.ejianc.business.procurement.plan.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 采购计划明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procurement_purchase_plan_detail")
public class PurchasePlanDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="delivery_date")
    private Date deliveryDate; // 要求到货日期
    @TableField(value="material_code")
    private String materialCode; // 档案编码
    @TableField(value="material_name")
    private String materialName; // 档案名称
    @TableField(value="material_type_name")
    private String materialTypeName; // 分类名称
    @TableField(value="material_type_code")
    private String materialTypeCode; // 分类编码
    @TableField(value="spec")
    private String spec; // 规则/型号
    @TableField(value="unit_name")
    private String unitName; // 计量单位
    @TableField(value="brand")
    private String brand; // 品牌
    @TableField(value="place")
    private String place; // 产地
    @TableField(value="material_attribute")
    private String materialAttribute; // 材质属性
    @TableField(value="standard_number")
    private String standardNumber; // 标准号
    @TableField(value="manufacturer")
    private String manufacturer; // 制造商
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="purchase_place")
    private String purchasePlace; // 采购地点
    @TableField(value="delivery_place")
    private String deliveryPlace; // 交货地点
    @TableField(value="supplier_names")
    private String supplierNames; // 推荐的潜在供应商名称及联系方式
    @TableField(value="subject_name")
    private String subjectName; // 成本科目名称
    @TableField(value="source_bill_id")
    private String sourceBillId; // 来源数据主表Id
    @TableField(value="source_type")
    private String sourceType; // 来源类型：1-物资档案,2-工程档案,3-服务档案,4-需求计划,5-采购策划
    @TableField(value="source_bill_code")
    private String sourceBillCode; // 来源数据编码
    @TableField(value="source_id")
    private String sourceId; // 来源Id
    @TableField(value="purchase_category_name")
    private String purchaseCategoryName; // 一级集采类别名称
    @TableField(value="usefor_name")
    private String useforName; // 用途名称
    @TableField(value="wbs_name")
    private String wbsName; // 工程部位名称
    @TableField(value="usage_category_name")
    private String usageCategoryName; // 材料/设备使用类别名称
    @TableField(value="plan_object")
    private String planObject; // 采购标的
    @TableField(value="plan_permission_type")
    private Integer planPermissionType; // 采购计划实施权限 1-一级集采，2-二级集采，3-所属单位，4-项目经理部
    @TableField(value="auth_permission_type")
    private Integer authPermissionType; // 授权实施权限 1-一级集采，2-二级集采，3-所属单位，4-项目经理部
    @TableField(value="auth_status")
    private Integer authStatus; // 是否已授权 1-是，2-否
    @TableField(value="allocate_status")
    private Integer allocateStatus; // 是否已分配 1-是，2-否
    @TableField(value="plan_id")
    private Long planId; // 计划Id
    @TableField(value="material_id")
    private Long materialId; // 档案Id
    @TableField(value="material_type_id")
    private Long materialTypeId; // 分类Id
    @TableField(value="unit_id")
    private Long unitId; // 计量单位主键
    @TableField(value="subject_id")
    private Long subjectId; // 成本科目id
    @TableField(value="purchase_category_id")
    private Long purchaseCategoryId; // 一级集采类别id
    @TableField(value="usefor_id")
    private Long useforId; // 用途id
    @TableField(value="wbs_id")
    private Long wbsId; // 工程部位id
    @TableField(value="usage_category_id")
    private Long usageCategoryId; // 材料/设备使用类别id
    @TableField(value="num")
    private BigDecimal num; // 采购计划数量

    @TableField(value="ctrl_detail_tax_mny")
    private BigDecimal ctrlDetailTaxMny; // 控制含税金额

    @TableField(value="ctrl_detail_tax_price")
    private BigDecimal ctrlDetailTaxPrice; // 控制含税单价

    @TableField(value="pre_detail_tax_mny")
    private BigDecimal preDetailTaxMny; // 预估含税金额

    @TableField(value="pre_detail_tax_price")
    private BigDecimal preDetailTaxPrice; // 预估含税单价

    @TableField(value="bid_detail_tax_mny")
    private BigDecimal bidlDetailTaxMny; // 投标含税金额

    @TableField(value="bid_detail_tax_price")
    private BigDecimal bidDetailTaxPrice; // 投标含税单价

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public BigDecimal getCtrlDetailTaxMny() {
        return ctrlDetailTaxMny;
    }

    public void setCtrlDetailTaxMny(BigDecimal ctrlDetailTaxMny) {
        this.ctrlDetailTaxMny = ctrlDetailTaxMny;
    }

    public BigDecimal getCtrlDetailTaxPrice() {
        return ctrlDetailTaxPrice;
    }

    public void setCtrlDetailTaxPrice(BigDecimal ctrlDetailTaxPrice) {
        this.ctrlDetailTaxPrice = ctrlDetailTaxPrice;
    }

    public BigDecimal getPreDetailTaxMny() {
        return preDetailTaxMny;
    }

    public void setPreDetailTaxMny(BigDecimal preDetailTaxMny) {
        this.preDetailTaxMny = preDetailTaxMny;
    }

    public BigDecimal getPreDetailTaxPrice() {
        return preDetailTaxPrice;
    }

    public void setPreDetailTaxPrice(BigDecimal preDetailTaxPrice) {
        this.preDetailTaxPrice = preDetailTaxPrice;
    }

    public BigDecimal getBidlDetailTaxMny() {
        return bidlDetailTaxMny;
    }

    public void setBidlDetailTaxMny(BigDecimal bidlDetailTaxMny) {
        this.bidlDetailTaxMny = bidlDetailTaxMny;
    }

    public BigDecimal getBidDetailTaxPrice() {
        return bidDetailTaxPrice;
    }

    public void setBidDetailTaxPrice(BigDecimal bidDetailTaxPrice) {
        this.bidDetailTaxPrice = bidDetailTaxPrice;
    }

    public Date getDeliveryDate() {
        return deliveryDate;
    }

    public void setDeliveryDate(Date deliveryDate) {
        this.deliveryDate = deliveryDate;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getBrand() {
        return brand;
    }

    public void setBrand(String brand) {
        this.brand = brand;
    }
    public String getPlace() {
        return place;
    }

    public void setPlace(String place) {
        this.place = place;
    }
    public String getMaterialAttribute() {
        return materialAttribute;
    }

    public void setMaterialAttribute(String materialAttribute) {
        this.materialAttribute = materialAttribute;
    }
    public String getStandardNumber() {
        return standardNumber;
    }

    public void setStandardNumber(String standardNumber) {
        this.standardNumber = standardNumber;
    }
    public String getManufacturer() {
        return manufacturer;
    }

    public void setManufacturer(String manufacturer) {
        this.manufacturer = manufacturer;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getPurchasePlace() {
        return purchasePlace;
    }

    public void setPurchasePlace(String purchasePlace) {
        this.purchasePlace = purchasePlace;
    }
    public String getDeliveryPlace() {
        return deliveryPlace;
    }

    public void setDeliveryPlace(String deliveryPlace) {
        this.deliveryPlace = deliveryPlace;
    }
    public String getSupplierNames() {
        return supplierNames;
    }

    public void setSupplierNames(String supplierNames) {
        this.supplierNames = supplierNames;
    }
    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }
    public String getSourceBillId() {
        return sourceBillId;
    }

    public void setSourceBillId(String sourceBillId) {
        this.sourceBillId = sourceBillId;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public String getSourceBillCode() {
        return sourceBillCode;
    }

    public void setSourceBillCode(String sourceBillCode) {
        this.sourceBillCode = sourceBillCode;
    }
    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
    public String getPurchaseCategoryName() {
        return purchaseCategoryName;
    }

    public void setPurchaseCategoryName(String purchaseCategoryName) {
        this.purchaseCategoryName = purchaseCategoryName;
    }
    public String getUseforName() {
        return useforName;
    }

    public void setUseforName(String useforName) {
        this.useforName = useforName;
    }
    public String getWbsName() {
        return wbsName;
    }

    public void setWbsName(String wbsName) {
        this.wbsName = wbsName;
    }
    public String getUsageCategoryName() {
        return usageCategoryName;
    }

    public void setUsageCategoryName(String usageCategoryName) {
        this.usageCategoryName = usageCategoryName;
    }
    public String getPlanObject() {
        return planObject;
    }

    public void setPlanObject(String planObject) {
        this.planObject = planObject;
    }
    public Integer getPlanPermissionType() {
        return planPermissionType;
    }

    public void setPlanPermissionType(Integer planPermissionType) {
        this.planPermissionType = planPermissionType;
    }
    public Integer getAuthPermissionType() {
        return authPermissionType;
    }

    public void setAuthPermissionType(Integer authPermissionType) {
        this.authPermissionType = authPermissionType;
    }
    public Integer getAuthStatus() {
        return authStatus;
    }

    public void setAuthStatus(Integer authStatus) {
        this.authStatus = authStatus;
    }
    public Integer getAllocateStatus() {
        return allocateStatus;
    }

    public void setAllocateStatus(Integer allocateStatus) {
        this.allocateStatus = allocateStatus;
    }
    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public Long getSubjectId() {
        return subjectId;
    }

    public void setSubjectId(Long subjectId) {
        this.subjectId = subjectId;
    }
    public Long getPurchaseCategoryId() {
        return purchaseCategoryId;
    }

    public void setPurchaseCategoryId(Long purchaseCategoryId) {
        this.purchaseCategoryId = purchaseCategoryId;
    }
    public Long getUseforId() {
        return useforId;
    }

    public void setUseforId(Long useforId) {
        this.useforId = useforId;
    }
    public Long getWbsId() {
        return wbsId;
    }

    public void setWbsId(Long wbsId) {
        this.wbsId = wbsId;
    }
    public Long getUsageCategoryId() {
        return usageCategoryId;
    }

    public void setUsageCategoryId(Long usageCategoryId) {
        this.usageCategoryId = usageCategoryId;
    }
    
}

==> ejc-procurement-impl-3.0.0-20251216.064159-131-sources.jar: com/ejianc/business/procurement/plan/bean/PurchasePlanDetailEntity.java <==
package com.ejianc.business.procurement.plan.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 采购计划明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procurement_purchase_plan_detail")
public class PurchasePlanDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="delivery_date")
    private Date deliveryDate; // 要求到货日期
    @TableField(value="material_code")
    private String materialCode; // 档案编码
    @TableField(value="material_name")
    private String materialName; // 档案名称
    @TableField(value="material_type_name")
    private String materialTypeName; // 分类名称
    @TableField(value="material_type_code")
    private String materialTypeCode; // 分类编码
    @TableField(value="spec")
    private String spec; // 规则/型号
    @TableField(value="unit_name")
    private String unitName; // 计量单位
    @TableField(value="brand")
    private String brand; // 品牌
    @TableField(value="place")
    private String place; // 产地
    @TableField(value="material_attribute")
    private String materialAttribute; // 材质属性
    @TableField(value="standard_number")
    private String standardNumber; // 标准号
    @TableField(value="manufacturer")
    private String manufacturer; // 制造商
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="purchase_place")
    private String purchasePlace; // 采购地点
    @TableField(value="delivery_place")
    private String deliveryPlace; // 交货地点
    @TableField(value="supplier_names")
    private String supplierNames; // 推荐的潜在供应商名称及联系方式
    @TableField(value="subject_name")
    private String subjectName; // 成本科目名称
    @TableField(value="source_bill_id")
    private String sourceBillId; // 来源数据主表Id
    @TableField(value="source_type")
    private String sourceType; // 来源类型：1-物资档案,2-工程档案,3-服务档案,4-需求计划,5-采购策划
    @TableField(value="source_bill_code")
    private String sourceBillCode; // 来源数据编码
    @TableField(value="source_id")
    private String sourceId; // 来源Id
    @TableField(value="purchase_category_name")
    private String purchaseCategoryName; // 一级集采类别名称
    @TableField(value="usefor_name")
    private String useforName; // 用途名称
    @TableField(value="wbs_name")
    private String wbsName; // 工程部位名称
    @TableField(value="usage_category_name")
    private String usageCategoryName; // 材料/设备使用类别名称
    @TableField(value="plan_object")
    private String planObject; // 采购标的
    @TableField(value="plan_permission_type")
    private Integer planPermissionType; // 采购计划实施权限 1-一级集采，2-二级集采，3-所属单位，4-项目经理部
    @TableField(value="auth_permission_type")
    private Integer authPermissionType; // 授权实施权限 1-一级集采，2-二级集采，3-所属单位，4-项目经理部
    @TableField(value="auth_status")
    private Integer authStatus; // 是否已授权 1-是，2-否
    @TableField(value="allocate_status")
    private Integer allocateStatus; // 是否已分配 1-是，2-否
    @TableField(value="plan_id")
    private Long planId; // 计划Id
    @TableField(value="material_id")
    private Long materialId; // 档案Id
    @TableField(value="material_type_id")
    private Long materialTypeId; // 分类Id
    @TableField(value="unit_id")
    private Long unitId; // 计量单位主键
    @TableField(value="subject_id")
    private Long subjectId; // 成本科目id
    @TableField(value="purchase_category_id")
    private Long purchaseCategoryId; // 一级集采类别id
    @TableField(value="usefor_id")
    private Long useforId; // 用途id
    @TableField(value="wbs_id")
    private Long wbsId; // 工程部位id
    @TableField(value="usage_category_id")
    private Long usageCategoryId; // 材料/设备使用类别id
    @TableField(value="num")
    private BigDecimal num; // 采购计划数量

    @TableField(value="ctrl_detail_tax_mny")
    private BigDecimal ctrlDetailTaxMny; // 控制含税金额

    @TableField(value="ctrl_detail_tax_price")
    private BigDecimal ctrlDetailTaxPrice; // 控制含税单价

    @TableField(value="pre_detail_tax_mny")
    private BigDecimal preDetailTaxMny; // 预估含税金额

    @TableField(value="pre_detail_tax_price")
    private BigDecimal preDetailTaxPrice; // 预估含税单价

    @TableField(value="bid_detail_tax_mny")
    private BigDecimal bidDetailTaxMny; // 投标含税金额

    @TableField(value="bid_detail_tax_price")
    private BigDecimal bidDetailTaxPrice; // 投标含税单价

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public BigDecimal getCtrlDetailTaxMny() {
        return ctrlDetailTaxMny;
    }

    public void setCtrlDetailTaxMny(BigDecimal ctrlDetailTaxMny) {
        this.ctrlDetailTaxMny = ctrlDetailTaxMny;
    }

    public BigDecimal getCtrlDetailTaxPrice() {
        return ctrlDetailTaxPrice;
    }

    public void setCtrlDetailTaxPrice(BigDecimal ctrlDetailTaxPrice) {
        this.ctrlDetailTaxPrice = ctrlDetailTaxPrice;
    }

    public BigDecimal getPreDetailTaxMny() {
        return preDetailTaxMny;
    }

    public void setPreDetailTaxMny(BigDecimal preDetailTaxMny) {
        this.preDetailTaxMny = preDetailTaxMny;
    }

    public BigDecimal getPreDetailTaxPrice() {
        return preDetailTaxPrice;
    }

    public void setPreDetailTaxPrice(BigDecimal preDetailTaxPrice) {
        this.preDetailTaxPrice = preDetailTaxPrice;
    }

    public BigDecimal getBidDetailTaxMny() {
        return bidDetailTaxMny;
    }

    public void setBidDetailTaxMny(BigDecimal bidDetailTaxMny) {
        this.bidDetailTaxMny = bidDetailTaxMny;
    }

    public BigDecimal getBidDetailTaxPrice() {
        return bidDetailTaxPrice;
    }

    public void setBidDetailTaxPrice(BigDecimal bidDetailTaxPrice) {
        this.bidDetailTaxPrice = bidDetailTaxPrice;
    }

    public Date getDeliveryDate() {
        return deliveryDate;
    }

    public void setDeliveryDate(Date deliveryDate) {
        this.deliveryDate = deliveryDate;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getBrand() {
        return brand;
    }

    public void setBrand(String brand) {
        this.brand = brand;
    }
    public String getPlace() {
        return place;
    }

    public void setPlace(String place) {
        this.place = place;
    }
    public String getMaterialAttribute() {
        return materialAttribute;
    }

    public void setMaterialAttribute(String materialAttribute) {
        this.materialAttribute = materialAttribute;
    }
    public String getStandardNumber() {
        return standardNumber;
    }

    public void setStandardNumber(String standardNumber) {
        this.standardNumber = standardNumber;
    }
    public String getManufacturer() {
        return manufacturer;
    }

    public void setManufacturer(String manufacturer) {
        this.manufacturer = manufacturer;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getPurchasePlace() {
        return purchasePlace;
    }

    public void setPurchasePlace(String purchasePlace) {
        this.purchasePlace = purchasePlace;
    }
    public String getDeliveryPlace() {
        return deliveryPlace;
    }

    public void setDeliveryPlace(String deliveryPlace) {
        this.deliveryPlace = deliveryPlace;
    }
    public String getSupplierNames() {
        return supplierNames;
    }

    public void setSupplierNames(String supplierNames) {
        this.supplierNames = supplierNames;
    }
    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }
    public String getSourceBillId() {
        return sourceBillId;
    }

    public void setSourceBillId(String sourceBillId) {
        this.sourceBillId = sourceBillId;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public String getSourceBillCode() {
        return sourceBillCode;
    }

    public void setSourceBillCode(String sourceBillCode) {
        this.sourceBillCode = sourceBillCode;
    }
    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
    public String getPurchaseCategoryName() {
        return purchaseCategoryName;
    }

    public void setPurchaseCategoryName(String purchaseCategoryName) {
        this.purchaseCategoryName = purchaseCategoryName;
    }
    public String getUseforName() {
        return useforName;
    }

    public void setUseforName(String useforName) {
        this.useforName = useforName;
    }
    public String getWbsName() {
        return wbsName;
    }

    public void setWbsName(String wbsName) {
        this.wbsName = wbsName;
    }
    public String getUsageCategoryName() {
        return usageCategoryName;
    }

    public void setUsageCategoryName(String usageCategoryName) {
        this.usageCategoryName = usageCategoryName;
    }
    public String getPlanObject() {
        return planObject;
    }

    public void setPlanObject(String planObject) {
        this.planObject = planObject;
    }
    public Integer getPlanPermissionType() {
        return planPermissionType;
    }

    public void setPlanPermissionType(Integer planPermissionType) {
        this.planPermissionType = planPermissionType;
    }
    public Integer getAuthPermissionType() {
        return authPermissionType;
    }

    public void setAuthPermissionType(Integer authPermissionType) {
        this.authPermissionType = authPermissionType;
    }
    public Integer getAuthStatus() {
        return authStatus;
    }

    public void setAuthStatus(Integer authStatus) {
        this.authStatus = authStatus;
    }
    public Integer getAllocateStatus() {
        return allocateStatus;
    }

    public void setAllocateStatus(Integer allocateStatus) {
        this.allocateStatus = allocateStatus;
    }
    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public Long getSubjectId() {
        return subjectId;
    }

    public void setSubjectId(Long subjectId) {
        this.subjectId = subjectId;
    }
    public Long getPurchaseCategoryId() {
        return purchaseCategoryId;
    }

    public void setPurchaseCategoryId(Long purchaseCategoryId) {
        this.purchaseCategoryId = purchaseCategoryId;
    }
    public Long getUseforId() {
        return useforId;
    }

    public void setUseforId(Long useforId) {
        this.useforId = useforId;
    }
    public Long getWbsId() {
        return wbsId;
    }

    public void setWbsId(Long wbsId) {
        this.wbsId = wbsId;
    }
    public Long getUsageCategoryId() {
        return usageCategoryId;
    }

    public void setUsageCategoryId(Long usageCategoryId) {
        this.usageCategoryId = usageCategoryId;
    }
    
}
